@@ -71,11 +71,14 @@ module YARD
     #   docstring. May be nil.
     # @param [String] raw_data the complete docstring, including all
     #   original formatting and any unparsed tags/directives.
-    def self.new!(text, tags = [], object = nil, raw_data = nil)
+    # @param [CodeObjects::Base, nil] ref_object a reference object used for
+    #   the base set of documentation / tag information.
+    def self.new!(text, tags = [], object = nil, raw_data = nil, ref_object = nil)
       docstring = allocate
       docstring.replace(text, false)
       docstring.object = object
       docstring.add_tag(*tags)
+      docstring.instance_variable_set("@unresolved_reference", ref_object)
       docstring.instance_variable_set("@all", raw_data) if raw_data
       docstring
     end
@@ -118,13 +121,23 @@ module YARD
       end
     end
 
+    def to_s
+      resolve_reference
+      super
+    end
+
     # Replaces the docstring with new raw content. Called by {#all=}.
     # @param [String] content the raw comments to be parsed
     def replace(content, parse = true)
       content = content.join("\n") if content.is_a?(Array)
       @tags, @ref_tags = [], []
-      @all = content
-      super(parse ? parse_comments(content) : content)
+      if parse
+        super(parse_comments(content))
+      else
+        @all = content
+        @unresolved_reference = nil
+        super(content)
+      end
     end
     alias all= replace
 
@@ -136,6 +149,7 @@ module YARD
     # @return [Docstring] a new copied docstring
     # @since 0.7.0
     def dup
+      resolve_reference
       obj = super
       %w(all summary tags ref_tags).each do |name|
         val = instance_variable_get("@#{name}")
@@ -155,14 +169,16 @@ module YARD
     # Gets the first line of a docstring to the period or the first paragraph.
     # @return [String] The first line or paragraph of the docstring; always ends with a period.
     def summary
+      resolve_reference
       return @summary if @summary
+      stripped = self.gsub(/<.+?>/m, '').strip
       open_parens = ['{', '(', '[']
       close_parens = ['}', ')', ']']
       num_parens = 0
       idx = length.times do |index|
-        case self[index, 1]
+        case stripped[index, 1]
         when ".", "\r", "\n"
-          next_char = self[index + 1, 1].to_s
+          next_char = stripped[index + 1, 1].to_s
           if num_parens == 0 && next_char =~ /^\s*$/
             break index - 1
           end
@@ -172,8 +188,10 @@ module YARD
           num_parens -= 1
         end
       end
-      @summary = self[0..idx]
-      @summary += '.' unless @summary.empty?
+      @summary = stripped[0..idx]
+      if !@summary.empty? && @summary !~ /\A\s*\{include:.+\}\s*\Z/
+        @summary += '.'
+      end
       @summary
     end
 
@@ -191,6 +209,13 @@ module YARD
           unless tag.docstring.blank?
             tag_text += "\n" + tag.docstring.all.gsub(/\r?\n/, "\n  ")
           end
+        when Tags::OptionTag
+          tag_text = "@#{tag.tag_name} #{tag.name}"
+          tag_text += ' [' + tag.pair.types.join(', ') + ']' if tag.pair.types
+          tag_text += ' ' + tag.pair.name.to_s if tag.pair.name
+          tag_text += "\n " if tag.name && tag.text
+          tag_text += ' (' + tag.pair.defaults.join(', ') + ')' if tag.pair.defaults
+          tag_text += " " + tag.pair.text.strip.gsub(/\n/, "\n  ") if tag.pair.text
         else
           tag_text = '@' + tag.tag_name
           tag_text += ' [' + tag.types.join(', ') + ']' if tag.types
@@ -289,6 +314,26 @@ module YARD
 
     # @endgroup
 
+    # Resolves unresolved other docstring reference if there is
+    # unresolved reference. Does nothing if there is no unresolved
+    # reference.
+    #
+    # Normally, you don't need to call this method
+    # explicitly. Resolving unresolved reference is done implicitly.
+    #
+    # @return [void]
+    def resolve_reference
+      loop do
+        return if @unresolved_reference.nil?
+        return if CodeObjects::Proxy === @unresolved_reference
+
+        reference, @unresolved_reference = @unresolved_reference, nil
+        resolved_tags = reference.docstring.tags
+        self.all = [reference.docstring.all, @all].join("\n")
+        add_tag(*resolved_tags)
+      end
+    end
+
     private
 
     # Maps valid reference tags
@@ -310,6 +355,8 @@ module YARD
     def parse_comments(comments)
       parser = self.class.parser
       parser.parse(comments, object)
+      @all = parser.raw_text
+      @unresolved_reference = parser.reference
       add_tag(*parser.tags)
       parser.text
     end
