@@ -205,7 +205,7 @@ module YARD
     #
     # === Escaping Interpolation
     #
-    # Interpolation can be escaped by prefixing the +$+ with +\+, like so:
+    # Interpolation can be escaped by prefixing the +$+ with +\\\+, like so:
     #
     #     # @!macro foo
     #     #   I have \$2.00 USD.
@@ -266,8 +266,9 @@ module YARD
       end
 
       def attach?
-         class_method? || # always attach to class methods
-          (tag.types && tag.types.include?('attach'))
+        new? && # must have data or there is nothing to attach
+        class_method? || # always attach to class methods
+        (tag.types && tag.types.include?('attach'))
       end
 
       def class_method?
@@ -403,7 +404,7 @@ module YARD
         obj.signature = method_signature
         obj.parameters = OverloadTag.new(:overload, method_signature).parameters
         obj.docstring = Docstring.new!(parser.text, parser.tags, obj,
-          parser.raw_text)
+          parser.raw_text, parser.reference)
         handler.register_module_function(obj)
         obj
       end
