@@ -52,6 +52,11 @@ describe YARD::Docstring do
       5.times { o1.summary.should == "Hello." }
     end
 
+    it "should strip HTML before summarizing" do
+      doc = Docstring.new("<p>Hello <b>world</b></p>.")
+      doc.summary.should == 'Hello world.'
+    end
+
     it "should return the first sentence" do
       o = Docstring.new("DOCSTRING. Another sentence")
       o.summary.should == "DOCSTRING."
@@ -83,6 +88,12 @@ describe YARD::Docstring do
       doc.summary.should == "Returns a list of tags specified by +name+ or all tags if +name+ is not specified."
     end
 
+    it "should not attach period if entire summary is include" do
+      YARD.parse_string "# docstring\ndef foo; end"
+      Docstring.new("{include:#foo}").summary.should == '{include:#foo}'
+      Registry.clear
+    end
+
     it "should handle references embedded in summary" do
       Docstring.new("Aliasing {Test.test}. Done.").summary.should == "Aliasing {Test.test}."
     end
@@ -250,6 +261,18 @@ describe YARD::Docstring do
       doc = Docstring.new("123\n@param")
       doc.to_raw.should == doc.all
     end
+
+    # @bug gh-563
+    it "should handle full @option tags" do
+      doc = Docstring.new("@option foo [String] bar (nil) baz")
+      doc.to_raw.should == "@option foo [String] bar (nil) baz"
+    end
+
+    # @bug gh-563
+    it "should handle simple @option tags" do
+      doc = Docstring.new("@option foo :key bar")
+      doc.to_raw.should == "@option foo :key bar"
+    end
   end
 
   describe '#dup' do
@@ -284,4 +307,19 @@ describe YARD::Docstring do
       doc.dup.line_range.should == doc.line_range
     end
   end
+
+  describe 'reference docstrings' do
+    it 'allows for construction of docstring with ref object' do
+      YARD.parse_string <<-eof
+        class A
+          # Docstring
+          def a; end
+          # (see #a)
+          def b; end
+        end
+      eof
+      YARD::Registry.at('A#b').docstring.should == 'Docstring'
+      YARD::Registry.clear
+    end
+  end
 end
