@@ -546,9 +546,14 @@ describe YARD::Parser::SourceParser do
           parser = Parser::SourceParser.new
           File.should_receive(:read_binary).with('tmpfile').and_return(src)
           result = parser.parse("tmpfile")
-          if HAVE_RIPPER && RUBY19
-            ['Shift_JIS', 'Windows-31J', 'UTF-8'].send(msg, include(
-              result.enumerator[0].source.encoding.to_s))
+          if HAVE_RIPPER && YARD.ruby19?
+            if msg == :should_not
+              default_encoding = 'UTF-8'
+              result.enumerator[0].source.encoding.to_s.should eq(default_encoding)
+            else
+              ['Shift_JIS', 'Windows-31J', 'UTF-8'].send(msg, include(
+                result.enumerator[0].source.encoding.to_s))
+            end
           end
           result.encoding_line.send(msg) == src.split("\n").last
         end
@@ -572,7 +577,7 @@ describe YARD::Parser::SourceParser do
           ['UTF-8'].send(msg, include(content.encoding.to_s))
         end
       end
-    end if RUBY19
+    end if YARD.ruby19?
 
     Parser::SourceParser::ENCODING_BYTE_ORDER_MARKS.each do |encoding, bom|
       it "should understand #{encoding.upcase} BOM" do
@@ -584,7 +589,7 @@ describe YARD::Parser::SourceParser do
         Registry.all(:class).first.path.should == "FooBar"
         result.enumerator[0].source.encoding.to_s.downcase.should == encoding
       end
-    end if HAVE_RIPPER && RUBY19
+    end if HAVE_RIPPER && YARD.ruby19?
   end
 
   describe '#parse_in_order' do
@@ -606,16 +611,32 @@ describe YARD::Parser::SourceParser do
       end
     end
 
-    it "should attempt to order files by length (process toplevel files first)" do
-      %w(a a/b a/b/c).each do |file|
+    it "should attempt to order files by length for globs (process toplevel files first)" do
+      files = %w(a a/b a/b/c)
+      files.each do |file|
         File.should_receive(:file?).with(file).and_return(true)
         File.should_receive(:read_binary).with(file).ordered.and_return('')
       end
-      YARD.parse %w(a/b/c a/b a)
+      Dir.should_receive(:[]).with('a/**/*').and_return(files.reverse)
+      YARD.parse 'a/**/*'
+    end
+
+    it "should allow overriding of length sorting when single file is presented" do
+      files = %w(a/b/c a a/b)
+      files.each do |file|
+        File.should_receive(:file?).with(file).at_least(1).times.and_return(true)
+        File.should_receive(:read_binary).with(file).ordered.and_return('')
+      end
+      Dir.should_receive(:[]).with('a/**/*').and_return(files.reverse)
+      YARD.parse ['a/b/c', 'a/**/*']
     end
   end
 
   describe '#parse_statements' do
+    before do
+      Registry.clear
+    end
+
     it "should display a warning for invalid parser type" do
       log.should_receive(:warn).with(/unrecognized file/)
       log.should_receive(:backtrace)
@@ -624,15 +645,13 @@ describe YARD::Parser::SourceParser do
 
     if HAVE_RIPPER
       it "should display a warning for a syntax error (with new parser)" do
-        err_msg = "Syntax error in `(stdin)`:(1,3): syntax error, unexpected $undefined, expecting $end"
-        log.should_receive(:warn).with(err_msg)
+        log.should_receive(:warn).with(/Syntax error in/)
         log.should_receive(:backtrace)
         YARD::Parser::SourceParser.parse_string("$$$", :ruby)
       end
     end
 
     it "should handle groups" do
-      Registry.clear
       YARD.parse_string <<-eof
         class A
           # @group Group Name
@@ -654,5 +673,45 @@ describe YARD::Parser::SourceParser do
       Registry.at('A#foo2').group.should == "Group Name"
       Registry.at('A#baz').group.should == "Group 2"
     end
+
+    it 'handles multi-line class/module references' do
+      YARD.parse_string <<-eof
+        class A::
+          B::C; end
+      eof
+      Registry.all.should == [P('A::B::C')]
+    end
+
+    it 'handles sclass definitions of multi-line class/module references' do
+      YARD.parse_string <<-eof
+        class << A::
+          B::C
+          def foo; end
+        end
+      eof
+      Registry.all.size.should == 2
+      Registry.at('A::B::C').should_not be_nil
+      Registry.at('A::B::C.foo').should_not be_nil
+    end
+
+    it 'handles lone comment blocks at the end of a namespace' do
+      YARD.parse_string <<-eof
+        module A
+          class B
+            def c; end
+
+            # @!method d
+          end
+        end
+      eof
+      Registry.at('A#d').should be_nil
+      Registry.at('A::B#d').should_not be_nil
+    end
+
+    it 'supports keyword arguments' do
+      YARD.parse_string 'def foo(a: 1, b: 2, **kwargs) end'
+      args = [['a:', '1'], ['b:', '2'], ['**kwargs', nil]]
+      Registry.at('#foo').parameters.should eq(args)
+    end if YARD.ruby2?
   end
 end
